@@ -1,6 +1,4 @@
-SECRET_KEY = "bootstrap3isawesome"
-
-USE_TZ = True
+SECRET_KEY = "Thanks for using django-bootstrap4!"
 
 DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}
 
@@ -12,18 +10,19 @@ INSTALLED_APPS = (
     "django.contrib.sessions",
     "django.contrib.messages",
     "django.contrib.staticfiles",
+    "django.contrib.gis",
     # Our tests
-    "bootstrap3",
+    "bootstrap4",
     "tests",
 )
 
 ROOT_URLCONF = "tests.app.urls"
 
-MIDDLEWARE = [
-    "django.contrib.sessions.middleware.SessionMiddleware",  # required for django.contrib.admin
+MIDDLEWARE = (
+    "django.contrib.sessions.middleware.SessionMiddleware",
     "django.contrib.auth.middleware.AuthenticationMiddleware",  # required for django.contrib.admin
     "django.contrib.messages.middleware.MessageMiddleware",  # required for django.contrib.admin
-]
+)
 
 STATIC_URL = "/static/"
 
@@ -46,10 +45,10 @@ TEMPLATES = [
     }
 ]
 
-BOOTSTRAP3 = {
+BOOTSTRAP4 = {
     "theme_url": "//example.com/theme.css",
     "javascript_in_head": True,
-    "required_css_class": "bootstrap3-req",
-    "error_css_class": "bootstrap3-err",
-    "success_css_class": "bootstrap3-bound",
+    "required_css_class": "bootstrap4-req",
+    "error_css_class": "bootstrap4-err",
+    "success_css_class": "bootstrap4-bound",
 }
